@@ -1,12 +1,16 @@
 package Twitter::API::Trait::AppAuth;
 # ABSTRACT: App-only (OAuth2) Authentication
-$Twitter::API::Trait::AppAuth::VERSION = '0.0103'; # TRIAL
+$Twitter::API::Trait::AppAuth::VERSION = '0.0104'; # TRIAL
 use Moo::Role;
 use Carp;
-use HTTP::Request::Common qw/POST/;
 use URL::Encode qw/url_encode url_decode/;
 use namespace::clean;
 
+requires qw/
+    _url_for access_token add_authorization api_url consumer_key
+    consumer_secret finalize_request request request_access_token
+/;
+
 # private methods
 
 sub oauth2_url_for {
@@ -24,7 +28,7 @@ my $add_consumer_auth_header = sub {
 
 # public methods
 
-#pod =method get_bearer_token
+#pod =method oauth2_token
 #pod
 #pod Call the C<oauth2/token> endpoint to get a bearer token. The token is not
 #pod stored in Twitter::API's state. If you want that, set the C<access_token>
@@ -34,10 +38,10 @@ my $add_consumer_auth_header = sub {
 #pod
 #pod =cut
 
-sub get_bearer_token {
+sub oauth2_token {
     my $self = shift;
 
-    my $r = $self->request(post => $self->oauth2_url_for('token'), {
+    my ( $r, $c ) = $self->request(post => $self->oauth2_url_for('token'), {
         -add_consumer_auth_header => 1,
         grant_type => 'client_credentials',
     });
@@ -45,7 +49,8 @@ sub get_bearer_token {
     # In their wisdom, Twitter sends us a URL encoded token. We need to decode
     # it, so if/when we call invalidate_token, and properly URL encode our
     # parameters, we don't end up with a double-encoded token.
-    return url_decode($$r{access_token});
+    my $token = url_decode $$r{access_token};
+    return wantarray ? ( $token, $c ) : $token;
 }
 
 #pod =method invalidate_token($token)
@@ -59,10 +64,13 @@ sub get_bearer_token {
 sub invalidate_token {
     my ( $self, $token ) = @_;
 
-    $self->request(post =>$self->oauth2_url_for('invalidate_token'), {
-        -add_consumer_auth_header => 1,
-        access_token              => $token,
+    my ( $r, $c ) = $self->request(
+        post =>$self->oauth2_url_for('invalidate_token'), {
+            -add_consumer_auth_header => 1,
+            access_token              => $token,
     });
+    my $token_returned = url_decode $$r{access_token};
+    return wantarray ? ( $token_returned, $c ) : $token_returned;
 }
 
 # request chain modifiers
@@ -102,7 +110,7 @@ Twitter::API::Trait::AppAuth - App-only (OAuth2) Authentication
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -110,7 +118,7 @@ version 0.0103
     my $client = Twitter::API->new_with_traits(
         traits => [ qw/ApiMethods AppAuth/ ]);
 
-    my $r = $client->get_bearer_token;
+    my $r = $client->oauth2_token;
     # return value is hash ref:
     # { token_type => 'bearer', access_token => 'AA...' }
     my $token = $r->{access_token};
@@ -130,7 +138,7 @@ version 0.0103
 
 =head1 METHODS
 
-=head2 get_bearer_token
+=head2 oauth2_token
 
 Call the C<oauth2/token> endpoint to get a bearer token. The token is not
 stored in Twitter::API's state. If you want that, set the C<access_token>
